package rks.consumer;

import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.ConsumerConfig;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.common.serialization.StringDeserializer;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.CommandLineRunner;
import org.springframework.context.annotation.Bean;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.kafka.config.ConcurrentKafkaListenerContainerFactory;
import org.springframework.kafka.core.ConsumerFactory;
import org.springframework.kafka.core.DefaultKafkaConsumerFactory;
import org.springframework.stereotype.Component;
import rks.entity.Employee;

import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
@Slf4j
@Component
public class EmployeeConsumer implements CommandLineRunner {

    @Value("${spring.kafka.topic}")
    private String topic;

    @Value("${spring.output.file}")
    private String outputFile;

    @KafkaListener(topics = {"employee-producer"}, groupId = "employee-group")
    public void listen(ConsumerRecord<Integer, String> message) {
        // Here you can parse the message to create an Employee object
        // Assuming message is a CSV string, you can split it or use a library like Jackson to convert it
        log.info("Employee data read from kafka : {}", message);
//        String[] parts = message.split(",");
//        Employee employee = new Employee(parts[0], parts[1], parts[2]);
//        log.info("Employee data read from kafka : {}", employee);
//
//        // Write to CSV
//        writeEmployeeToCSV(employee);
    }

    private void writeEmployeeToCSV(Employee employee) {
        try (BufferedWriter writer = new BufferedWriter(new FileWriter(outputFile, true))) {
            writer.write(employee.toString());
            writer.newLine();
            log.info("data written in csv file");
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    @Override
    public void run(String... args) {

        System.out.println("Listening for messages on topic: " + topic);
    }
}
